@@ -11,7 +11,6 @@ __all__ = ('AnyValue', )
 class _AnyValue(_Parser[_t.Any]):
     """A validator for an ``Any`` value. This will allow any value.
     """
-
     @staticmethod
     def describe() -> str:
         """The description for the any parser.
@@ -20,7 +19,7 @@ class _AnyValue(_Parser[_t.Any]):
 
     @staticmethod
     def _to_open_api(_: _OpenAPISchema) -> _t.Mapping[str, _t.Any]:
-        return {'type': 'object'}
+        return {}
 
     @staticmethod
     def try_parse(value: object) -> _t.Any:
