@@ -2,6 +2,7 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import os
 import typing as t
 
 import cg_request_args as rqa
@@ -11,9 +12,9 @@ from cg_maybe.utils import maybe_from_nullable
 from .. import parsers, utils
 from ..models.ignore_handling import IgnoreHandling
 
-if t.TYPE_CHECKING:
-    from ..client import AuthenticatedClient, _BaseClient
-    from ..models.any_error import AnyError
+if t.TYPE_CHECKING or os.getenv("CG_EAGERIMPORT", False):
+    import codegrade
+
     from ..models.assignment import Assignment
     from ..models.assignment_feedback import AssignmentFeedback
     from ..models.assignment_grader import AssignmentGrader
@@ -23,6 +24,7 @@ if t.TYPE_CHECKING:
     from ..models.assignment_peer_feedback_settings import (
         AssignmentPeerFeedbackSettings,
     )
+    from ..models.assignment_template import AssignmentTemplate
     from ..models.auto_test import AutoTest
     from ..models.comment_base import CommentBase
     from ..models.copy_rubric_assignment_data import CopyRubricAssignmentData
@@ -32,6 +34,9 @@ if t.TYPE_CHECKING:
     from ..models.import_into_assignment_data import ImportIntoAssignmentData
     from ..models.job import Job
     from ..models.patch_assignment_data import PatchAssignmentData
+    from ..models.patch_submit_types_assignment_data import (
+        PatchSubmitTypesAssignmentData,
+    )
     from ..models.plagiarism_run import PlagiarismRun
     from ..models.put_rubric_assignment_data import PutRubricAssignmentData
     from ..models.rubric_row_base import RubricRowBase
@@ -44,17 +49,18 @@ if t.TYPE_CHECKING:
     from ..models.webhook_base import WebhookBase
     from ..models.work import Work
 
-_ClientT = t.TypeVar("_ClientT", bound="_BaseClient")
+
+_ClientT = t.TypeVar("_ClientT", bound="codegrade.client._BaseClient")
 
 
 class AssignmentService(t.Generic[_ClientT]):
     __slots__ = ("__client",)
 
-    def __init__(self, client: "_BaseClient") -> None:
+    def __init__(self, client: _ClientT) -> None:
         self.__client = client
 
     def get_rubric(
-        self: "AssignmentService[AuthenticatedClient]",
+        self: "AssignmentService[codegrade.client.AuthenticatedClient]",
         *,
         assignment_id: "int",
         extra_parameters: t.Mapping[
@@ -67,7 +73,7 @@ class AssignmentService(t.Generic[_ClientT]):
         :param extra_parameters: The extra query parameters you might want to
             add. By default no extra query parameters are added.
 
-        :returns: A list of `RubricRows` items.
+        :returns: A list of `RubricRow` items.
         """
 
         url = "/api/v1/assignments/{assignmentId}/rubrics/".format(
@@ -101,7 +107,7 @@ class AssignmentService(t.Generic[_ClientT]):
         )
 
     def put_rubric(
-        self: "AssignmentService[AuthenticatedClient]",
+        self: "AssignmentService[codegrade.client.AuthenticatedClient]",
         json_body: t.Union[dict, list, "PutRubricAssignmentData"],
         *,
         assignment_id: "int",
@@ -112,9 +118,9 @@ class AssignmentService(t.Generic[_ClientT]):
         """Add or update rubric of an assignment.
 
         :param json_body: The body of the request. See
-            :model:`.PutRubricAssignmentData` for information about the
+            :class:`.PutRubricAssignmentData` for information about the
             possible fields. You can provide this data as a
-            :model:`.PutRubricAssignmentData` or as a dictionary.
+            :class:`.PutRubricAssignmentData` or as a dictionary.
         :param assignment_id: The id of the assignment
         :param extra_parameters: The extra query parameters you might want to
             add. By default no extra query parameters are added.
@@ -155,7 +161,7 @@ class AssignmentService(t.Generic[_ClientT]):
         )
 
     def delete_rubric(
-        self: "AssignmentService[AuthenticatedClient]",
+        self: "AssignmentService[codegrade.client.AuthenticatedClient]",
         *,
         assignment_id: "int",
         extra_parameters: t.Mapping[
@@ -199,7 +205,7 @@ class AssignmentService(t.Generic[_ClientT]):
         )
 
     def get(
-        self: "AssignmentService[AuthenticatedClient]",
+        self: "AssignmentService[codegrade.client.AuthenticatedClient]",
         *,
         assignment_id: "int",
         extra_parameters: t.Mapping[
@@ -246,7 +252,7 @@ class AssignmentService(t.Generic[_ClientT]):
         )
 
     def delete(
-        self: "AssignmentService[AuthenticatedClient]",
+        self: "AssignmentService[codegrade.client.AuthenticatedClient]",
         *,
         assignment_id: "int",
         extra_parameters: t.Mapping[
@@ -289,7 +295,7 @@ class AssignmentService(t.Generic[_ClientT]):
         )
 
     def patch(
-        self: "AssignmentService[AuthenticatedClient]",
+        self: "AssignmentService[codegrade.client.AuthenticatedClient]",
         json_body: t.Union[dict, list, "PatchAssignmentData"],
         *,
         assignment_id: "int",
@@ -300,9 +306,9 @@ class AssignmentService(t.Generic[_ClientT]):
         """Update the given assignment with new values.
 
         :param json_body: The body of the request. See
-            :model:`.PatchAssignmentData` for information about the possible
+            :class:`.PatchAssignmentData` for information about the possible
             fields. You can provide this data as a
-            :model:`.PatchAssignmentData` or as a dictionary.
+            :class:`.PatchAssignmentData` or as a dictionary.
         :param assignment_id: The id of the assignment you want to update.
         :param extra_parameters: The extra query parameters you might want to
             add. By default no extra query parameters are added.
@@ -342,8 +348,98 @@ class AssignmentService(t.Generic[_ClientT]):
             ),
         )
 
+    def get_template(
+        self: "AssignmentService[codegrade.client.AuthenticatedClient]",
+        *,
+        assignment_id: "int",
+        extra_parameters: t.Mapping[
+            str, t.Union[str, bool, int, float]
+        ] = None,
+    ) -> "AssignmentTemplate":
+        """Return the template corresponding to the given `assignment_id`.
+
+        :param assignment_id: The id of the assignment.
+        :param extra_parameters: The extra query parameters you might want to
+            add. By default no extra query parameters are added.
+
+        :returns: The template for this assignment.
+        """
+
+        url = "/api/v1/assignments/{assignmentId}/template".format(
+            assignmentId=assignment_id
+        )
+        params = extra_parameters or {}
+
+        with self.__client as client:
+            resp = client.http.get(url=url, params=params)
+        utils.log_warnings(resp)
+
+        if utils.response_code_matches(resp.status_code, 200):
+            # fmt: off
+            from ..models.assignment_template import AssignmentTemplate
+
+            # fmt: on
+            return parsers.JsonResponseParser(
+                parsers.ParserFor.make(AssignmentTemplate)
+            ).try_parse(resp)
+
+        from ..models.any_error import AnyError
+
+        raise utils.get_error(
+            resp,
+            (
+                (
+                    (400, 409, 401, 403, 404, "5XX"),
+                    utils.unpack_union(AnyError),
+                ),
+            ),
+        )
+
+    def delete_template(
+        self: "AssignmentService[codegrade.client.AuthenticatedClient]",
+        *,
+        assignment_id: "int",
+        extra_parameters: t.Mapping[
+            str, t.Union[str, bool, int, float]
+        ] = None,
+    ) -> "None":
+        """Delete the template corresponding to the given `assignment_id`.
+
+        :param assignment_id: The id of the assignment.
+        :param extra_parameters: The extra query parameters you might want to
+            add. By default no extra query parameters are added.
+
+        :returns: Nothing.
+        """
+
+        url = "/api/v1/assignments/{assignmentId}/template".format(
+            assignmentId=assignment_id
+        )
+        params = extra_parameters or {}
+
+        with self.__client as client:
+            resp = client.http.delete(url=url, params=params)
+        utils.log_warnings(resp)
+
+        if utils.response_code_matches(resp.status_code, 204):
+            # fmt: off
+            # fmt: on
+            return parsers.ConstantlyParser(None).try_parse(resp)
+
+        from ..models.any_error import AnyError
+
+        raise utils.get_error(
+            resp,
+            (
+                (
+                    (400, 409, 401, 403, 404, "5XX"),
+                    utils.unpack_union(AnyError),
+                ),
+            ),
+        )
+
     def update_peer_feedback_settings(
-        self: "AssignmentService[AuthenticatedClient]",
+        self: "AssignmentService[codegrade.client.AuthenticatedClient]",
         json_body: t.Union[
             dict, list, "UpdatePeerFeedbackSettingsAssignmentData"
         ],
@@ -356,9 +452,9 @@ class AssignmentService(t.Generic[_ClientT]):
         """Enable peer feedback for an assignment.
 
         :param json_body: The body of the request. See
-            :model:`.UpdatePeerFeedbackSettingsAssignmentData` for information
+            :class:`.UpdatePeerFeedbackSettingsAssignmentData` for information
             about the possible fields. You can provide this data as a
-            :model:`.UpdatePeerFeedbackSettingsAssignmentData` or as a
+            :class:`.UpdatePeerFeedbackSettingsAssignmentData` or as a
             dictionary.
         :param assignment_id: The id of the assignment for which you want to
             enable peer feedback.
@@ -405,7 +501,7 @@ class AssignmentService(t.Generic[_ClientT]):
         )
 
     def disable_peer_feedback(
-        self: "AssignmentService[AuthenticatedClient]",
+        self: "AssignmentService[codegrade.client.AuthenticatedClient]",
         *,
         assignment_id: "int",
         extra_parameters: t.Mapping[
@@ -451,7 +547,7 @@ class AssignmentService(t.Generic[_ClientT]):
         )
 
     def export(
-        self: "AssignmentService[AuthenticatedClient]",
+        self: "AssignmentService[codegrade.client.AuthenticatedClient]",
         json_body: t.Union[dict, list, "ExportAssignmentData"],
         *,
         assignment_id: "int",
@@ -462,9 +558,9 @@ class AssignmentService(t.Generic[_ClientT]):
         """Generate a CSV report for this assignment.
 
         :param json_body: The body of the request. See
-            :model:`.ExportAssignmentData` for information about the possible
+            :class:`.ExportAssignmentData` for information about the possible
             fields. You can provide this data as a
-            :model:`.ExportAssignmentData` or as a dictionary.
+            :class:`.ExportAssignmentData` or as a dictionary.
         :param assignment_id: The id of the assignment
         :param extra_parameters: The extra query parameters you might want to
             add. By default no extra query parameters are added.
@@ -505,7 +601,7 @@ class AssignmentService(t.Generic[_ClientT]):
         )
 
     def get_all(
-        self: "AssignmentService[AuthenticatedClient]",
+        self: "AssignmentService[codegrade.client.AuthenticatedClient]",
         *,
         only_with_rubric: "bool" = False,
         extra_parameters: t.Mapping[
@@ -555,7 +651,7 @@ class AssignmentService(t.Generic[_ClientT]):
         )
 
     def get_all_graders(
-        self: "AssignmentService[AuthenticatedClient]",
+        self: "AssignmentService[codegrade.client.AuthenticatedClient]",
         *,
         assignment_id: "int",
         extra_parameters: t.Mapping[
@@ -602,7 +698,7 @@ class AssignmentService(t.Generic[_ClientT]):
         )
 
     def get_submissions_by_user(
-        self: "AssignmentService[AuthenticatedClient]",
+        self: "AssignmentService[codegrade.client.AuthenticatedClient]",
         *,
         assignment_id: "int",
         user_id: "int",
@@ -654,7 +750,7 @@ class AssignmentService(t.Generic[_ClientT]):
         )
 
     def get_all_submissions(
-        self: "AssignmentService[AuthenticatedClient]",
+        self: "AssignmentService[codegrade.client.AuthenticatedClient]",
         *,
         assignment_id: "int",
         extended: "bool" = False,
@@ -716,7 +812,7 @@ class AssignmentService(t.Generic[_ClientT]):
         )
 
     def get_all_feedback(
-        self: "AssignmentService[AuthenticatedClient]",
+        self: "AssignmentService[codegrade.client.AuthenticatedClient]",
         *,
         assignment_id: "int",
         extra_parameters: t.Mapping[
@@ -765,21 +861,22 @@ class AssignmentService(t.Generic[_ClientT]):
         )
 
     def get_auto_test(
-        self: "AssignmentService[AuthenticatedClient]",
+        self: "AssignmentService[codegrade.client.AuthenticatedClient]",
         *,
         assignment_id: "int",
         extra_parameters: t.Mapping[
             str, t.Union[str, bool, int, float]
         ] = None,
     ) -> "AutoTest":
-        """Get the AutoTest for this assignment.
+        """Get the `AutoTest` for this assignment.
 
         :param assignment_id: The id of the assignment from which you want to
-            get the AutoTest.
+            get the `AutoTest`.
         :param extra_parameters: The extra query parameters you might want to
             add. By default no extra query parameters are added.
 
-        :returns: The AutoTest for the given assignment, if it has an AutoTest.
+        :returns: The `AutoTest` for the given assignment, if it has an
+                  `AutoTest`.
         """
 
         url = "/api/v1/assignments/{assignmentId}/auto_test".format(
@@ -813,7 +910,7 @@ class AssignmentService(t.Generic[_ClientT]):
         )
 
     def get_comments_by_user(
-        self: "AssignmentService[AuthenticatedClient]",
+        self: "AssignmentService[codegrade.client.AuthenticatedClient]",
         *,
         assignment_id: "int",
         user_id: "int",
@@ -854,11 +951,11 @@ class AssignmentService(t.Generic[_ClientT]):
 
         if utils.response_code_matches(resp.status_code, 200):
             # fmt: off
-            from ..models.comment_base import CommentBase
+            from ..models.comment_base import CommentBaseParser
 
             # fmt: on
             return parsers.JsonResponseParser(
-                rqa.List(parsers.ParserFor.make(CommentBase))
+                rqa.List(CommentBaseParser)
             ).try_parse(resp)
 
         from ..models.any_error import AnyError
@@ -874,7 +971,7 @@ class AssignmentService(t.Generic[_ClientT]):
         )
 
     def get_course(
-        self: "AssignmentService[AuthenticatedClient]",
+        self: "AssignmentService[codegrade.client.AuthenticatedClient]",
         *,
         assignment_id: "int",
         extra_parameters: t.Mapping[
@@ -922,7 +1019,7 @@ class AssignmentService(t.Generic[_ClientT]):
         )
 
     def get_webhook_settings(
-        self: "AssignmentService[AuthenticatedClient]",
+        self: "AssignmentService[codegrade.client.AuthenticatedClient]",
         *,
         assignment_id: "int",
         webhook_type: "t.Literal['git']",
@@ -990,7 +1087,7 @@ class AssignmentService(t.Generic[_ClientT]):
         )
 
     def get_member_states(
-        self: "AssignmentService[AuthenticatedClient]",
+        self: "AssignmentService[codegrade.client.AuthenticatedClient]",
         *,
         assignment_id: "int",
         group_id: "int",
@@ -1042,7 +1139,7 @@ class AssignmentService(t.Generic[_ClientT]):
         )
 
     def get_peer_feedback_subjects(
-        self: "AssignmentService[AuthenticatedClient]",
+        self: "AssignmentService[codegrade.client.AuthenticatedClient]",
         *,
         assignment_id: "int",
         user_id: "int",
@@ -1099,7 +1196,7 @@ class AssignmentService(t.Generic[_ClientT]):
         )
 
     def get_all_plagiarism_runs(
-        self: "AssignmentService[AuthenticatedClient]",
+        self: "AssignmentService[codegrade.client.AuthenticatedClient]",
         *,
         assignment_id: "int",
         extra_parameters: t.Mapping[
@@ -1147,7 +1244,7 @@ class AssignmentService(t.Generic[_ClientT]):
         )
 
     def import_into(
-        self: "AssignmentService[AuthenticatedClient]",
+        self: "AssignmentService[codegrade.client.AuthenticatedClient]",
         json_body: t.Union[dict, list, "ImportIntoAssignmentData"],
         *,
         into_assignment_id: "int",
@@ -1158,9 +1255,9 @@ class AssignmentService(t.Generic[_ClientT]):
         """Import an assignment into another assignment.
 
         :param json_body: The body of the request. See
-            :model:`.ImportIntoAssignmentData` for information about the
+            :class:`.ImportIntoAssignmentData` for information about the
             possible fields. You can provide this data as a
-            :model:`.ImportIntoAssignmentData` or as a dictionary.
+            :class:`.ImportIntoAssignmentData` or as a dictionary.
         :param into_assignment_id: The assignment you want to import into.
         :param extra_parameters: The extra query parameters you might want to
             add. By default no extra query parameters are added.
@@ -1202,7 +1299,7 @@ class AssignmentService(t.Generic[_ClientT]):
         )
 
     def copy_rubric(
-        self: "AssignmentService[AuthenticatedClient]",
+        self: "AssignmentService[codegrade.client.AuthenticatedClient]",
         json_body: t.Union[dict, list, "CopyRubricAssignmentData"],
         *,
         assignment_id: "int",
@@ -1213,9 +1310,9 @@ class AssignmentService(t.Generic[_ClientT]):
         """Import a rubric from a different assignment.
 
         :param json_body: The body of the request. See
-            :model:`.CopyRubricAssignmentData` for information about the
+            :class:`.CopyRubricAssignmentData` for information about the
             possible fields. You can provide this data as a
-            :model:`.CopyRubricAssignmentData` or as a dictionary.
+            :class:`.CopyRubricAssignmentData` or as a dictionary.
         :param assignment_id: The id of the assignment in which you want to
             import the rubric. This assignment shouldn't have a rubric.
         :param extra_parameters: The extra query parameters you might want to
@@ -1259,7 +1356,7 @@ class AssignmentService(t.Generic[_ClientT]):
         )
 
     def mark_grader_as_done(
-        self: "AssignmentService[AuthenticatedClient]",
+        self: "AssignmentService[codegrade.client.AuthenticatedClient]",
         *,
         assignment_id: "int",
         grader_id: "int",
@@ -1271,8 +1368,7 @@ class AssignmentService(t.Generic[_ClientT]):
 
         :param assignment_id: The id of the assignment the grader is done
             grading.
-        :param grader_id: The id of the :class:.models.User that is done
-            grading.
+        :param grader_id: The id of the `User` that is done grading.
         :param extra_parameters: The extra query parameters you might want to
             add. By default no extra query parameters are added.
 
@@ -1307,7 +1403,7 @@ class AssignmentService(t.Generic[_ClientT]):
         )
 
     def mark_grader_as_not_done(
-        self: "AssignmentService[AuthenticatedClient]",
+        self: "AssignmentService[codegrade.client.AuthenticatedClient]",
         *,
         assignment_id: "int",
         grader_id: "int",
@@ -1320,8 +1416,7 @@ class AssignmentService(t.Generic[_ClientT]):
 
         :param assignment_id: The id of the assignment the grader is not yet
             done grading.
-        :param grader_id: The id of the :class:.models.User that is not yet
-            done grading.
+        :param grader_id: The id of the `User` that is not yet done grading.
         :param extra_parameters: The extra query parameters you might want to
             add. By default no extra query parameters are added.
 
@@ -1355,8 +1450,67 @@ class AssignmentService(t.Generic[_ClientT]):
             ),
         )
 
+    def patch_submit_types(
+        self: "AssignmentService[codegrade.client.AuthenticatedClient]",
+        multipart_data: t.Union[dict, list, "PatchSubmitTypesAssignmentData"],
+        *,
+        assignment_id: "int",
+        extra_parameters: t.Mapping[
+            str, t.Union[str, bool, int, float]
+        ] = None,
+    ) -> "Assignment":
+        """Update the given assignment editor template with new files.
+
+        How this route deals with existing editor templates when submitting is
+        still experimental and might change in an upcoming release.
+
+        :param multipart_data: The data that should form the body of the
+            request. See :class:`.PatchSubmitTypesAssignmentData` for
+            information about the possible fields.
+        :param assignment_id: The id of the assignment for which you want to
+            update the editor template.
+        :param extra_parameters: The extra query parameters you might want to
+            add. By default no extra query parameters are added.
+
+        :returns: The updated assignment.
+        """
+
+        url = "/api/v1/assignments/{assignmentId}/submit_types".format(
+            assignmentId=assignment_id
+        )
+        params = extra_parameters or {}
+
+        with self.__client as client:
+            resp = client.http.patch(
+                url=url,
+                files=utils.to_multipart(utils.to_dict(multipart_data)),
+                params=params,
+            )
+        utils.log_warnings(resp)
+
+        if utils.response_code_matches(resp.status_code, 200):
+            # fmt: off
+            from ..models.assignment import Assignment
+
+            # fmt: on
+            return parsers.JsonResponseParser(
+                parsers.ParserFor.make(Assignment)
+            ).try_parse(resp)
+
+        from ..models.any_error import AnyError
+
+        raise utils.get_error(
+            resp,
+            (
+                (
+                    (400, 409, 401, 403, 404, "5XX"),
+                    utils.unpack_union(AnyError),
+                ),
+            ),
+        )
+
     def upload_submission(
-        self: "AssignmentService[AuthenticatedClient]",
+        self: "AssignmentService[codegrade.client.AuthenticatedClient]",
         multipart_data: t.Union[dict, list, "UploadSubmissionAssignmentData"],
         *,
         assignment_id: "int",
@@ -1370,7 +1524,7 @@ class AssignmentService(t.Generic[_ClientT]):
         """Upload one or more files as `Work` to the given `Assignment`.
 
         :param multipart_data: The data that should form the body of the
-            request. See :model:`.UploadSubmissionAssignmentData` for
+            request. See :class:`.UploadSubmissionAssignmentData` for
             information about the possible fields.
         :param assignment_id: The id of the assignment
         :param author_id: The id of the user for which we should get the
