@@ -15,6 +15,7 @@ if t.TYPE_CHECKING or os.getenv("CG_EAGERIMPORT", False):
 
     from ..models.create_tenant_data import CreateTenantData
     from ..models.extended_tenant import ExtendedTenant
+    from ..models.lti_provider_base import LTIProviderBase
     from ..models.partial_all_site_settings import PartialAllSiteSettings
     from ..models.patch_settings_tenant_data import PatchSettingsTenantData
     from ..models.patch_tenant_data import PatchTenantData
@@ -386,6 +387,53 @@ class TenantService(t.Generic[_ClientT]):
             ),
         )
 
+    def get_lti_providers(
+        self: "TenantService[codegrade.client.AuthenticatedClient]",
+        *,
+        tenant_id: "str",
+        extra_parameters: t.Mapping[
+            str, t.Union[str, bool, int, float]
+        ] = None,
+    ) -> "t.Sequence[LTIProviderBase]":
+        """List all LTI providers for this tenant.
+
+        :param tenant_id: The id of the tenant to get the LTI providers for.
+        :param extra_parameters: The extra query parameters you might want to
+            add. By default no extra query parameters are added.
+
+        :returns: A list of all known LTI providers.
+        """
+
+        url = "/api/v1/tenants/{tenantId}/lti_providers/".format(
+            tenantId=tenant_id
+        )
+        params = extra_parameters or {}
+
+        with self.__client as client:
+            resp = client.http.get(url=url, params=params)
+        utils.log_warnings(resp)
+
+        if utils.response_code_matches(resp.status_code, 200):
+            # fmt: off
+            from ..models.lti_provider_base import LTIProviderBaseParser
+
+            # fmt: on
+            return parsers.JsonResponseParser(
+                rqa.List(LTIProviderBaseParser)
+            ).try_parse(resp)
+
+        from ..models.any_error import AnyError
+
+        raise utils.get_error(
+            resp,
+            (
+                (
+                    (400, 409, 401, 403, 404, "5XX"),
+                    utils.unpack_union(AnyError),
+                ),
+            ),
+        )
+
     def get_settings(
         self,
         *,
