@@ -247,6 +247,9 @@ from .global_perm_map import GlobalPermMap
 from .global_permission import GlobalPermission
 from .grade_history import GradeHistory
 from .grade_origin import GradeOrigin
+from .grading_notifications_enabled_setting import (
+    GradingNotificationsEnabledSetting,
+)
 from .group import Group
 from .group_not_ready_for_submission_exception import (
     GroupNotReadyForSubmissionException,
@@ -320,6 +323,9 @@ from .max_normal_upload_size_setting import MaxNormalUploadSizeSetting
 from .max_number_of_files_setting import MaxNumberOfFilesSetting
 from .max_plagiarism_matches_setting import MaxPlagiarismMatchesSetting
 from .max_user_setting_amount_setting import MaxUserSettingAmountSetting
+from .metric_evaluation_time_chunk_size_setting import (
+    MetricEvaluationTimeChunkSizeSetting,
+)
 from .metric_evaluation_time_limit_setting import (
     MetricEvaluationTimeLimitSetting,
 )
