@@ -386,6 +386,9 @@ class AllSiteSettings(FrontendSiteSettings):
                 self.server_time_correction_enabled
             ),
             "METRIC_GATHERING_ENABLED": to_dict(self.metric_gathering_enabled),
+            "GRADING_NOTIFICATIONS_ENABLED": to_dict(
+                self.grading_notifications_enabled
+            ),
             "FEEDBACK_THREADS_INITIALLY_COLLAPSED": to_dict(
                 self.feedback_threads_initially_collapsed
             ),
@@ -399,6 +402,9 @@ class AllSiteSettings(FrontendSiteSettings):
             "METRIC_EVALUATION_TIME_LIMIT": to_dict(
                 self.metric_evaluation_time_limit
             ),
+            "METRIC_EVALUATION_TIME_CHUNK_SIZE": to_dict(
+                self.metric_evaluation_time_chunk_size
+            ),
             "METRIC_GATHERING_EXPRESSIONS": to_dict(
                 self.metric_gathering_expressions
             ),
@@ -474,11 +480,13 @@ class AllSiteSettings(FrontendSiteSettings):
             editor_enabled=parsed.EDITOR_ENABLED,
             server_time_correction_enabled=parsed.SERVER_TIME_CORRECTION_ENABLED,
             metric_gathering_enabled=parsed.METRIC_GATHERING_ENABLED,
+            grading_notifications_enabled=parsed.GRADING_NOTIFICATIONS_ENABLED,
             feedback_threads_initially_collapsed=parsed.FEEDBACK_THREADS_INITIALLY_COLLAPSED,
             metric_gathering_time_interval=parsed.METRIC_GATHERING_TIME_INTERVAL,
             metric_gathering_event_interval=parsed.METRIC_GATHERING_EVENT_INTERVAL,
             metric_event_buffer_size=parsed.METRIC_EVENT_BUFFER_SIZE,
             metric_evaluation_time_limit=parsed.METRIC_EVALUATION_TIME_LIMIT,
+            metric_evaluation_time_chunk_size=parsed.METRIC_EVALUATION_TIME_CHUNK_SIZE,
             metric_gathering_expressions=parsed.METRIC_GATHERING_EXPRESSIONS,
             server_time_diff_tolerance=parsed.SERVER_TIME_DIFF_TOLERANCE,
             server_time_sync_interval=parsed.SERVER_TIME_SYNC_INTERVAL,
