@@ -117,6 +117,11 @@ class FrontendSiteSettings:
     #: Whether the gathering of user behaviour events and subsequent metrics
     #: enabled.
     metric_gathering_enabled: "bool"
+    #: Whether teachers have access to the assignment manager -notifications
+    #: panel, which gives control over when to send notifications to graders to
+    #: finish their job, and also allows teachers to provide email(s) to notify
+    #: when all graders are finished.
+    grading_notifications_enabled: "bool"
     #: Feedback threads will start collapsed from this depth of the tree.
     feedback_threads_initially_collapsed: "int"
     #: The time interval between gathering of metrics.
@@ -127,9 +132,11 @@ class FrontendSiteSettings:
     #: The size of the circular buffer containing the trace of user behaviour
     #: events.
     metric_event_buffer_size: "int"
-    #: The size of the circular buffer containing the trace of user behaviour
-    #: events.
+    #: The total time limit for evaluating a single metric.
     metric_evaluation_time_limit: "datetime.timedelta"
+    #: The time before we yield to the event loop during evaluation of a
+    #: metric.
+    metric_evaluation_time_chunk_size: "datetime.timedelta"
     #: Expressions for the metrics we want to measure.
     metric_gathering_expressions: "t.Mapping[str, str]"
     #: The maximum amount of difference between the server time and the local
@@ -403,6 +410,17 @@ class FrontendSiteSettings:
                     " subsequent metrics enabled."
                 ),
             ),
+            rqa.RequiredArgument(
+                "GRADING_NOTIFICATIONS_ENABLED",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Whether teachers have access to the assignment manager"
+                    " -notifications panel, which gives control over when to"
+                    " send notifications to graders to finish their job, and"
+                    " also allows teachers to provide email(s) to notify when"
+                    " all graders are finished."
+                ),
+            ),
             rqa.RequiredArgument(
                 "FEEDBACK_THREADS_INITIALLY_COLLAPSED",
                 rqa.SimpleValue.int,
@@ -435,9 +453,14 @@ class FrontendSiteSettings:
             rqa.RequiredArgument(
                 "METRIC_EVALUATION_TIME_LIMIT",
                 rqa.RichValue.TimeDelta,
+                doc="The total time limit for evaluating a single metric.",
+            ),
+            rqa.RequiredArgument(
+                "METRIC_EVALUATION_TIME_CHUNK_SIZE",
+                rqa.RichValue.TimeDelta,
                 doc=(
-                    "The size of the circular buffer containing the trace of"
-                    " user behaviour events."
+                    "The time before we yield to the event loop during"
+                    " evaluation of a metric."
                 ),
             ),
             rqa.RequiredArgument(
@@ -533,6 +556,9 @@ class FrontendSiteSettings:
                 self.server_time_correction_enabled
             ),
             "METRIC_GATHERING_ENABLED": to_dict(self.metric_gathering_enabled),
+            "GRADING_NOTIFICATIONS_ENABLED": to_dict(
+                self.grading_notifications_enabled
+            ),
             "FEEDBACK_THREADS_INITIALLY_COLLAPSED": to_dict(
                 self.feedback_threads_initially_collapsed
             ),
@@ -546,6 +572,9 @@ class FrontendSiteSettings:
             "METRIC_EVALUATION_TIME_LIMIT": to_dict(
                 self.metric_evaluation_time_limit
             ),
+            "METRIC_EVALUATION_TIME_CHUNK_SIZE": to_dict(
+                self.metric_evaluation_time_chunk_size
+            ),
             "METRIC_GATHERING_EXPRESSIONS": to_dict(
                 self.metric_gathering_expressions
             ),
@@ -601,11 +630,13 @@ class FrontendSiteSettings:
             editor_enabled=parsed.EDITOR_ENABLED,
             server_time_correction_enabled=parsed.SERVER_TIME_CORRECTION_ENABLED,
             metric_gathering_enabled=parsed.METRIC_GATHERING_ENABLED,
+            grading_notifications_enabled=parsed.GRADING_NOTIFICATIONS_ENABLED,
             feedback_threads_initially_collapsed=parsed.FEEDBACK_THREADS_INITIALLY_COLLAPSED,
             metric_gathering_time_interval=parsed.METRIC_GATHERING_TIME_INTERVAL,
             metric_gathering_event_interval=parsed.METRIC_GATHERING_EVENT_INTERVAL,
             metric_event_buffer_size=parsed.METRIC_EVENT_BUFFER_SIZE,
             metric_evaluation_time_limit=parsed.METRIC_EVALUATION_TIME_LIMIT,
+            metric_evaluation_time_chunk_size=parsed.METRIC_EVALUATION_TIME_CHUNK_SIZE,
             metric_gathering_expressions=parsed.METRIC_GATHERING_EXPRESSIONS,
             server_time_diff_tolerance=parsed.SERVER_TIME_DIFF_TOLERANCE,
             server_time_sync_interval=parsed.SERVER_TIME_SYNC_INTERVAL,
