@@ -187,6 +187,11 @@ class PartialAllSiteSettings:
     #: Whether the gathering of user behaviour events and subsequent metrics
     #: enabled.
     metric_gathering_enabled: Maybe["bool"] = Nothing
+    #: Whether teachers have access to the assignment manager -notifications
+    #: panel, which gives control over when to send notifications to graders to
+    #: finish their job, and also allows teachers to provide email(s) to notify
+    #: when all graders are finished.
+    grading_notifications_enabled: Maybe["bool"] = Nothing
     #: Feedback threads will start collapsed from this depth of the tree.
     feedback_threads_initially_collapsed: Maybe["int"] = Nothing
     #: The maximum number of user settings stored per user.
@@ -201,9 +206,11 @@ class PartialAllSiteSettings:
     #: The size of the circular buffer containing the trace of user behaviour
     #: events.
     metric_event_buffer_size: Maybe["int"] = Nothing
-    #: The size of the circular buffer containing the trace of user behaviour
-    #: events.
+    #: The total time limit for evaluating a single metric.
     metric_evaluation_time_limit: Maybe["datetime.timedelta"] = Nothing
+    #: The time before we yield to the event loop during evaluation of a
+    #: metric.
+    metric_evaluation_time_chunk_size: Maybe["datetime.timedelta"] = Nothing
     #: Expressions for the metrics we want to measure.
     metric_gathering_expressions: Maybe["t.Mapping[str, str]"] = Nothing
     #: The maximum amount of difference between the server time and the local
@@ -644,6 +651,17 @@ class PartialAllSiteSettings:
                     " subsequent metrics enabled."
                 ),
             ),
+            rqa.OptionalArgument(
+                "GRADING_NOTIFICATIONS_ENABLED",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Whether teachers have access to the assignment manager"
+                    " -notifications panel, which gives control over when to"
+                    " send notifications to graders to finish their job, and"
+                    " also allows teachers to provide email(s) to notify when"
+                    " all graders are finished."
+                ),
+            ),
             rqa.OptionalArgument(
                 "FEEDBACK_THREADS_INITIALLY_COLLAPSED",
                 rqa.SimpleValue.int,
@@ -689,9 +707,14 @@ class PartialAllSiteSettings:
             rqa.OptionalArgument(
                 "METRIC_EVALUATION_TIME_LIMIT",
                 rqa.RichValue.TimeDelta,
+                doc="The total time limit for evaluating a single metric.",
+            ),
+            rqa.OptionalArgument(
+                "METRIC_EVALUATION_TIME_CHUNK_SIZE",
+                rqa.RichValue.TimeDelta,
                 doc=(
-                    "The size of the circular buffer containing the trace of"
-                    " user behaviour events."
+                    "The time before we yield to the event loop during"
+                    " evaluation of a metric."
                 ),
             ),
             rqa.OptionalArgument(
@@ -857,6 +880,9 @@ class PartialAllSiteSettings:
         self.metric_gathering_enabled = maybe_from_nullable(
             self.metric_gathering_enabled
         )
+        self.grading_notifications_enabled = maybe_from_nullable(
+            self.grading_notifications_enabled
+        )
         self.feedback_threads_initially_collapsed = maybe_from_nullable(
             self.feedback_threads_initially_collapsed
         )
@@ -878,6 +904,9 @@ class PartialAllSiteSettings:
         self.metric_evaluation_time_limit = maybe_from_nullable(
             self.metric_evaluation_time_limit
         )
+        self.metric_evaluation_time_chunk_size = maybe_from_nullable(
+            self.metric_evaluation_time_chunk_size
+        )
         self.metric_gathering_expressions = maybe_from_nullable(
             self.metric_gathering_expressions
         )
@@ -1080,6 +1109,10 @@ class PartialAllSiteSettings:
             res["METRIC_GATHERING_ENABLED"] = to_dict(
                 self.metric_gathering_enabled.value
             )
+        if self.grading_notifications_enabled.is_just:
+            res["GRADING_NOTIFICATIONS_ENABLED"] = to_dict(
+                self.grading_notifications_enabled.value
+            )
         if self.feedback_threads_initially_collapsed.is_just:
             res["FEEDBACK_THREADS_INITIALLY_COLLAPSED"] = to_dict(
                 self.feedback_threads_initially_collapsed.value
@@ -1108,6 +1141,10 @@ class PartialAllSiteSettings:
             res["METRIC_EVALUATION_TIME_LIMIT"] = to_dict(
                 self.metric_evaluation_time_limit.value
             )
+        if self.metric_evaluation_time_chunk_size.is_just:
+            res["METRIC_EVALUATION_TIME_CHUNK_SIZE"] = to_dict(
+                self.metric_evaluation_time_chunk_size.value
+            )
         if self.metric_gathering_expressions.is_just:
             res["METRIC_GATHERING_EXPRESSIONS"] = to_dict(
                 self.metric_gathering_expressions.value
@@ -1183,6 +1220,7 @@ class PartialAllSiteSettings:
             editor_enabled=parsed.EDITOR_ENABLED,
             server_time_correction_enabled=parsed.SERVER_TIME_CORRECTION_ENABLED,
             metric_gathering_enabled=parsed.METRIC_GATHERING_ENABLED,
+            grading_notifications_enabled=parsed.GRADING_NOTIFICATIONS_ENABLED,
             feedback_threads_initially_collapsed=parsed.FEEDBACK_THREADS_INITIALLY_COLLAPSED,
             max_user_setting_amount=parsed.MAX_USER_SETTING_AMOUNT,
             send_registration_email=parsed.SEND_REGISTRATION_EMAIL,
@@ -1190,6 +1228,7 @@ class PartialAllSiteSettings:
             metric_gathering_event_interval=parsed.METRIC_GATHERING_EVENT_INTERVAL,
             metric_event_buffer_size=parsed.METRIC_EVENT_BUFFER_SIZE,
             metric_evaluation_time_limit=parsed.METRIC_EVALUATION_TIME_LIMIT,
+            metric_evaluation_time_chunk_size=parsed.METRIC_EVALUATION_TIME_CHUNK_SIZE,
             metric_gathering_expressions=parsed.METRIC_GATHERING_EXPRESSIONS,
             server_time_diff_tolerance=parsed.SERVER_TIME_DIFF_TOLERANCE,
             server_time_sync_interval=parsed.SERVER_TIME_SYNC_INTERVAL,
